@@ -3,13 +3,14 @@ package App::Netdisco::Web::Plugin::Device::Addresses;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
 register_device_tab({ tag => 'addresses', label => 'Addresses' });
 
 # device interface addresses
-ajax '/ajax/content/device/addresses' => sub {
+ajax '/ajax/content/device/addresses' => require_login sub {
     my $q = param('q');
 
     my $device = schema('netdisco')->resultset('Device')
