@@ -3,6 +3,7 @@ package App::Netdisco::Web::Plugin::Report::PortUtilization;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
@@ -12,7 +13,7 @@ register_report({
   label => 'Port Utilization',
 });
 
-ajax '/ajax/content/report/portutilization' => sub {
+ajax '/ajax/content/report/portutilization' => require_login sub {
     return unless schema('netdisco')->resultset('Device')->count;
     my $set = schema('netdisco')->resultset('Virtual::PortUtilization');
 
